import { ListPage } from '../models/ListPage';
import { Searchable } from '../models/Searchable';
import { Sortable } from '../models/Sortable';
import { Filters } from '../models/Filters';
import { Address } from '../models/Address';
import { AddressAssignment } from '../models/AddressAssignment';
import { PartyType } from '../models/PartyType';
import { PartialDeep } from '../models/PartialDeep';
import { RequiredDeep } from '../models/RequiredDeep';
import { RequestOptions } from '../models/RequestOptions';
declare class Addresses {
    private impersonating;
    /**
    * @ignore
    * not part of public api, don't include in generated docs
    */
    constructor();
    /**
     * Get a list of addresses.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/addresses/list|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param listOptions.search Word or phrase to search for.
     * @param listOptions.searchOn Comma-delimited list of fields to search on.
     * @param listOptions.sortBy Comma-delimited list of fields to sort by.
     * @param listOptions.page Page of results to return. Default: 1. When paginating through many items (> page 30), we recommend the "Last ID" method, as outlined in the Advanced Querying documentation.
     * @param listOptions.pageSize Number of results to return per page. Default: 20, max: 100.
     * @param listOptions.filters An object or dictionary representing key/value pairs to apply as filters. Valid keys are top-level properties of the returned model or 'xp.???'
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    List<TAddress extends Address>(buyerID: string, listOptions?: {
        search?: string;
        searchOn?: Searchable<'Addresses.List'>;
        sortBy?: Sortable<'Addresses.List'>;
        page?: number;
        pageSize?: number;
        filters?: Filters;
    }, requestOptions?: RequestOptions): Promise<RequiredDeep<ListPage<TAddress>>>;
    /**
     * Create a new address. If ID is provided and an object with that ID already exists, a 409 (conflict) error is returned.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/addresses/create|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param address Required fields: Street1, City, State, Zip, Country
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Create<TAddress extends Address>(buyerID: string, address: Address, requestOptions?: RequestOptions): Promise<RequiredDeep<TAddress>>;
    /**
     * Get a single address.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/addresses/get|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param addressID ID of the address.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Get<TAddress extends Address>(buyerID: string, addressID: string, requestOptions?: RequestOptions): Promise<RequiredDeep<TAddress>>;
    /**
     * Create or update an address. If an object with the same ID already exists, it will be overwritten.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/addresses/save|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param addressID ID of the address.
     * @param address Required fields: Street1, City, State, Zip, Country
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Save<TAddress extends Address>(buyerID: string, addressID: string, address: Address, requestOptions?: RequestOptions): Promise<RequiredDeep<TAddress>>;
    /**
     * Delete an address.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/addresses/delete|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param addressID ID of the address.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Delete(buyerID: string, addressID: string, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Partially update an address.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/addresses/patch|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param addressID ID of the address.
     * @param address
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Patch<TAddress extends Address>(buyerID: string, addressID: string, address: PartialDeep<Address>, requestOptions?: RequestOptions): Promise<RequiredDeep<TAddress>>;
    /**
     * Delete an address assignment.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/addresses/delete-assignment|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param addressID ID of the address.
     * @param listOptions.userID ID of the user.
     * @param listOptions.userGroupID ID of the user group.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    DeleteAssignment(buyerID: string, addressID: string, listOptions?: {
        userID?: string;
        userGroupID?: string;
    }, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Get a list of address assignments.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/addresses/list-assignments|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param listOptions.addressID ID of the address.
     * @param listOptions.userID ID of the user.
     * @param listOptions.userGroupID ID of the user group.
     * @param listOptions.level Level of the address assignment. Possible values: User, Group, Company.
     * @param listOptions.isShipping Is shipping of the address assignment.
     * @param listOptions.isBilling Is billing of the address assignment.
     * @param listOptions.page Page of results to return. Default: 1. When paginating through many items (> page 30), we recommend the "Last ID" method, as outlined in the Advanced Querying documentation.
     * @param listOptions.pageSize Number of results to return per page. Default: 20, max: 100.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    ListAssignments<TAddressAssignment extends AddressAssignment>(buyerID: string, listOptions?: {
        addressID?: string;
        userID?: string;
        userGroupID?: string;
        level?: PartyType;
        isShipping?: boolean;
        isBilling?: boolean;
        page?: number;
        pageSize?: number;
    }, requestOptions?: RequestOptions): Promise<RequiredDeep<ListPage<TAddressAssignment>>>;
    /**
     * Create or update an address assignment.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/addresses/save-assignment|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param addressAssignment Required fields: AddressID
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    SaveAssignment(buyerID: string, addressAssignment: AddressAssignment, requestOptions?: RequestOptions): Promise<void>;
    /**
     * @description
     * enables impersonation by calling the subsequent method with the stored impersonation token
     *
     * @example
     * Addresses.As().List() // lists Addresses using the impersonated users' token
     */
    As(): this;
}
declare const _default: Addresses;
export default _default;
