import { ListPage } from '../models/ListPage';
import { Searchable } from '../models/Searchable';
import { Sortable } from '../models/Sortable';
import { Filters } from '../models/Filters';
import { Supplier } from '../models/Supplier';
import { SupplierBuyer } from '../models/SupplierBuyer';
import { PartialDeep } from '../models/PartialDeep';
import { RequiredDeep } from '../models/RequiredDeep';
import { RequestOptions } from '../models/RequestOptions';
declare class Suppliers {
    private impersonating;
    /**
    * @ignore
    * not part of public api, don't include in generated docs
    */
    constructor();
    /**
     * Get a list of suppliers.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/suppliers/list|api docs} for more info
     *
     * @param listOptions.search Word or phrase to search for.
     * @param listOptions.searchOn Comma-delimited list of fields to search on.
     * @param listOptions.sortBy Comma-delimited list of fields to sort by.
     * @param listOptions.page Page of results to return. Default: 1. When paginating through many items (> page 30), we recommend the "Last ID" method, as outlined in the Advanced Querying documentation.
     * @param listOptions.pageSize Number of results to return per page. Default: 20, max: 100.
     * @param listOptions.filters An object or dictionary representing key/value pairs to apply as filters. Valid keys are top-level properties of the returned model or 'xp.???'
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    List<TSupplier extends Supplier>(listOptions?: {
        search?: string;
        searchOn?: Searchable<'Suppliers.List'>;
        sortBy?: Sortable<'Suppliers.List'>;
        page?: number;
        pageSize?: number;
        filters?: Filters;
    }, requestOptions?: RequestOptions): Promise<RequiredDeep<ListPage<TSupplier>>>;
    /**
     * Create a new supplier. If ID is provided and an object with that ID already exists, a 409 (conflict) error is returned.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/suppliers/create|api docs} for more info
     *
     * @param supplier Required fields: Name
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Create<TSupplier extends Supplier>(supplier: Supplier, requestOptions?: RequestOptions): Promise<RequiredDeep<TSupplier>>;
    /**
     * Get a single supplier.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/suppliers/get|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Get<TSupplier extends Supplier>(supplierID: string, requestOptions?: RequestOptions): Promise<RequiredDeep<TSupplier>>;
    /**
     * Create or update a supplier. If an object with the same ID already exists, it will be overwritten.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/suppliers/save|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param supplier Required fields: Name
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Save<TSupplier extends Supplier>(supplierID: string, supplier: Supplier, requestOptions?: RequestOptions): Promise<RequiredDeep<TSupplier>>;
    /**
     * Delete a supplier.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/suppliers/delete|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Delete(supplierID: string, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Partially update a supplier.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/suppliers/patch|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param supplier
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Patch<TSupplier extends Supplier>(supplierID: string, supplier: PartialDeep<Supplier>, requestOptions?: RequestOptions): Promise<RequiredDeep<TSupplier>>;
    /**
     * Get a list of supplier buyers.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/suppliers/list-buyers|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param listOptions.search Word or phrase to search for.
     * @param listOptions.searchOn Comma-delimited list of fields to search on.
     * @param listOptions.sortBy Comma-delimited list of fields to sort by.
     * @param listOptions.page Page of results to return. Default: 1. When paginating through many items (> page 30), we recommend the "Last ID" method, as outlined in the Advanced Querying documentation.
     * @param listOptions.pageSize Number of results to return per page. Default: 20, max: 100.
     * @param listOptions.filters An object or dictionary representing key/value pairs to apply as filters. Valid keys are top-level properties of the returned model or 'xp.???'
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    ListBuyers<TSupplierBuyer extends SupplierBuyer>(supplierID: string, listOptions?: {
        search?: string;
        searchOn?: Searchable<'Suppliers.ListBuyers'>;
        sortBy?: Sortable<'Suppliers.ListBuyers'>;
        page?: number;
        pageSize?: number;
        filters?: Filters;
    }, requestOptions?: RequestOptions): Promise<RequiredDeep<ListPage<TSupplierBuyer>>>;
    /**
     * Create or update a supplier buyer.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/suppliers/save-buyer|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param buyerID ID of the buyer.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    SaveBuyer(supplierID: string, buyerID: string, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Delete a supplier buyer.
     * Check out the {@link https://ordercloud.io/api-reference/supplier/suppliers/delete-buyer|api docs} for more info
     *
     * @param supplierID ID of the supplier.
     * @param buyerID ID of the buyer.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    DeleteBuyer(supplierID: string, buyerID: string, requestOptions?: RequestOptions): Promise<void>;
    /**
     * @description
     * enables impersonation by calling the subsequent method with the stored impersonation token
     *
     * @example
     * Suppliers.As().List() // lists Suppliers using the impersonated users' token
     */
    As(): this;
}
declare const _default: Suppliers;
export default _default;
